import { Component, OnInit } from '@angular/core';
import { ApiService } from '../api.service';

@Component({
  selector: 'app-restexample',
  templateUrl: './restexample.component.html',
  styleUrls: ['./restexample.component.css']
})
export class RestexampleComponent implements OnInit {

  loading = false;
  loadingText = 'searching...';
  scrolledDown = false;
  showMovieDetails = false;
  movieDetails = {};

  data = {
    Search: []
  };

  page = 1;

  searchTitle = '';
  filmList = [];

  constructor(private apiService: ApiService) { }

  ngOnInit() {
  }

  searchQueryChanged(event: any) {
    this.searchTitle = event.target.value;
    if (this.searchTitle.length > 0) {
      this.loading = true;
      this.search().then((resolve) => {
        this.loading = false;
      }).catch((reject) => {
        this.loadingText = reject.Error;
      });
    } else {
      this.page = 1;
      this.data = {
        Search: []
      };
    }
  }

  loadMore() {
    this.page += 1;
    this.loading = true;
    this.search().then((resolve) => {
      this.loading = false;
      this.scrolledDown = false;
      window.scrollTo(0,document.body.scrollHeight);
    }).catch((reject) => {
      this.loadingText = reject.Error;
    });
  }

  search() {
    return new Promise((resolve, reject) => {
      this.apiService.search(this.searchTitle, this.page).subscribe((data) => {
        if (data.Response !== 'False') {
          for (let i = 0; i < data.Search.length; i++) {
            const newMovie = data.Search[i];
            newMovie.clicked = false;
            this.data.Search.push(data.Search[i]);
          }
          resolve();
        } else {
          reject(data);
        }
      }, error => {
        reject();
      });
    });
  }

  getMovieDetails(title: string) {
    return new Promise((resolve, reject) => {
      this.apiService.searchByTitle(title).subscribe((data) => {
        if (data.Response !== 'False') {
          this.movieDetails = data;
          resolve();
        } else {
          reject(data);
        }
      }, error => {
        reject();
      });
    });
  }

  openMovieDetails(MovieID: number) {
    this.getMovieDetails(this.data.Search[MovieID].Title).then(resolve => {
      this.showMovieDetails = true;
    });
  }

  closeMovieDetails() {
    this.showMovieDetails = false;
    this.movieDetails = {};
  }

}
